==> gl-transition-utils-1.0.0.tgz: package/lib/transformSource.test.js <==
"use strict";

var _transformSource = require("./transformSource");

var _transformSource2 = _interopRequireDefault(_transformSource);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

test("parse correctly burn.glsl", function () {
  var glsl = "\n// author: gre\n// license: MIT\nuniform vec3 color; // = vec3(0.9, 0.4, 0.2)\nvec4 transition (vec2 uv) {\n  return mix(\n    getFromColor(uv) + vec4(progress*color, 1.0),\n    getToColor(uv) + vec4((1.0-progress)*color, 1.0),\n    progress\n  );\n}\n  ";
  expect((0, _transformSource2.default)("burn.glsl", glsl)).toMatchSnapshot();
});

test("not providing a default creates a warning", function () {
  var glsl = "\n// Author: gre\n// License: MIT\nuniform vec3 color;\nvec4 transition (vec2 uv) {\n  return mix(\n    getFromColor(uv) + vec4(progress*color, 1.0),\n    getToColor(uv) + vec4((1.0-progress)*color, 1.0),\n    progress\n  );\n}\n  ";
  var res = (0, _transformSource2.default)("burn-2.glsl", glsl);
  expect(res.data).toMatchSnapshot();
  expect(res.errors.filter(function (e) {
    return e.type === "error";
  }).length).toBe(0);
  expect(res.errors.filter(function (e) {
    return e.type === "warn";
  }).length).toBe(1);
});

test("other example", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n  // author: gre\n  // License: MIT\n  uniform vec3 color /* = vec3(0.9, 0.4, 0.2) */;\n  uniform float foo; /* = 42. */\n  uniform sampler2D yo;\n  vec4 transition (/* weird comment in the middle */vec2 uv) {\n    return mix(\n    getFromColor(uv) + vec4(progress*color, 1.0),\n    getToColor(uv) + vec4((1.0-progress)*color, 1.0),\n    progress);\n  }\n  ");
  expect(res).toMatchSnapshot();
  expect(res.errors).toEqual([]);
});

test("must not override existing things", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\nuniform float from; /* = 42. */\nuniform float to; /* = 42. */\nvec4 transition (vec2 uv) {}\n");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("must define the transition function", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n\n");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("just the transition function is fine", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n      vec4 transition (vec2 uv) {\n        return vec4(0.0);\n      }\n  ");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBe(0);
});

test("you must define uv params", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n      vec4 transition () {\n        return vec4(0.0);\n      }\n  ");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("you must define the correct signature", function () {
  var res = (0, _transformSource2.default)("test.glsl", "void transition (vec2 uv) {}");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("crazy defaults", function () {
  var res = (0, _transformSource2.default)("crazyyyy.glsl", "\n // Author: Gaetan\n // License: LGPL\n uniform int yo; // = 1\n uniform vec4 yo2; // = vec4(4.4)\n uniform vec2 yo3 /* = vec2(1.1, 2.2) */;\n uniform float a,b; // = 42.2\n uniform float c /* = 3.3*/, d /* = 5.5 */;\n vec4 transition (vec2 uv) { return vec4(0.); }");
  expect(res.errors).toEqual([]);
  expect(res.data.defaultParams).toEqual({
    yo: 1,
    yo2: [4.4, 4.4, 4.4, 4.4],
    yo3: [1.1, 2.2],
    a: 42.2,
    b: 42.2,
    c: 3.3,
    d: 5.5
  });
  expect(res.data.author).toEqual("Gaetan");
  expect(res.data.license).toEqual("LGPL");
});

==> gl-transition-utils-1.3.6.tgz: package/lib/transformSource.test.js <==
"use strict";

var _transformSource = require("./transformSource");

var _transformSource2 = _interopRequireDefault(_transformSource);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

test("parse correctly burn.glsl", function () {
  var glsl = "\n// author: gre\n// license: MIT\nuniform vec3 color; // = vec3(0.9, 0.4, 0.2)\nvec4 transition (vec2 uv) {\n  return mix(\n    getFromColor(uv) + vec4(progress*color, 1.0),\n    getToColor(uv) + vec4((1.0-progress)*color, 1.0),\n    progress\n  );\n}\n  ";
  expect((0, _transformSource2.default)("burn.glsl", glsl)).toMatchSnapshot();
});

test("not providing a default creates a warning", function () {
  var glsl = "\n// Author: gre\n// License: MIT\nuniform vec3 color;\nvec4 transition (vec2 uv) {\n  return mix(\n    getFromColor(uv) + vec4(progress*color, 1.0),\n    getToColor(uv) + vec4((1.0-progress)*color, 1.0),\n    progress\n  );\n}\n  ";
  var res = (0, _transformSource2.default)("burn-2.glsl", glsl);
  expect(res.data).toMatchSnapshot();
  expect(res.errors.filter(function (e) {
    return e.type === "error";
  })).toEqual([]);
  expect(res.errors.filter(function (e) {
    return e.type === "warn";
  }).length).toBe(1);
});

test("other example", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n  // author: gre\n  // License: MIT\n  uniform vec3 color /* = vec3(0.9, 0.4, 0.2) */;\n  uniform float foo; /* = 42. */\n  uniform sampler2D yo;\n  vec4 transition (/* weird comment in the middle */vec2 uv) {\n    return mix(\n    getFromColor(uv) + vec4(progress*color, 1.0),\n    getToColor(uv) + vec4((1.0-progress)*color, 1.0),\n    progress);\n  }\n  ");
  expect(res).toMatchSnapshot();
  expect(res.errors).toEqual([]);
});

test("must not override existing things", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\nuniform float from; /* = 42. */\nuniform float to; /* = 42. */\nvec4 transition (vec2 uv) {}\n");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("must define the transition function", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n\n");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("must define metas", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n    vec4 transition (vec2 uv) {\n      return vec4(0.0);\n    }\n");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("simple transition function is fine", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n      // Author: gre\n      // License: MIT\n      vec4 transition (vec2 uv) {\n        return vec4(0.0);\n      }\n  ");
  expect(res).toMatchSnapshot();
  expect(res.errors).toEqual([]);
});

test("must define uv params", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n      // Author: gre\n      // License: MIT\n      vec4 transition () {\n        return vec4(0.0);\n      }\n  ");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("renaming param is fine", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n      // Author: gre\n      // License: MIT\n      vec4 transition (vec2 p) {\n        return vec4(p, 1.0, 1.0);\n      }\n  ");
  expect(res).toMatchSnapshot();
  expect(res.errors).toEqual([]);
});

test("must define the correct signature", function () {
  var res = (0, _transformSource2.default)("test.glsl", "\n    // Author: gre\n    // License: MIT\n    void transition (vec2 uv) {}");
  expect(res).toMatchSnapshot();
  expect(res.errors.length).toBeGreaterThan(0);
});

test("crazy defaults", function () {
  var res = (0, _transformSource2.default)("crazyyyy.glsl", "\n // Author: Gaetan\n // License: LGPL\n uniform int yo; // = 1\n uniform vec4 yo2; // = vec4(4.4)\n uniform vec2 yo3 /* = vec2(1.1, 2.2) */;\n uniform float a,b; // = 42.2\n uniform float c /* = 3.3*/, d /* = 5.5 */;\n vec4 transition (vec2 uv) { return vec4(0.); }");
  expect(res.errors).toEqual([]);
  expect(res.data.defaultParams).toEqual({
    yo: 1,
    yo2: [4.4, 4.4, 4.4, 4.4],
    yo3: [1.1, 2.2],
    a: 42.2,
    b: 42.2,
    c: 3.3,
    d: 5.5
  });
  expect(res.data.author).toEqual("Gaetan");
  expect(res.data.license).toEqual("LGPL");
});
